import { Image, Input, Text, View } from "@tarojs/components"
import back from '@/images/back.png'
import checked from '@/images/checked.png'
import eyeClose from '@/images/eyeClose.png'
import eye from '@/images/eye.png'
import './index.scss'
import { Button } from "@nutui/nutui-react-taro"
import { useState } from "react"
import Taro from "@tarojs/taro"
import backNav from '@/images/backNav.png'
import { phoneManage, sendCode } from "../../utils/api"
import { closeLoading, errorNotice, loading, redirectTo, successNotice } from "../../utils/utils"

const activeEye = eye

const Login = () => {

    const [account, setAccount] = useState('')
    const [pwd, setPwd] = useState()
    const [showPwd, setShowPwd] = useState(false)

    const [mobile, setMobile] = useState('')
    const [smsCode, setSmsCode] = useState('')
    const [interval, setIntervalTime] = useState(0)


    // 返回页面
    const backFn = () => {
        Taro.getCurrentPages().length > 0 && Taro.navigateBack()
    }


    // 倒计时
    const countDown = async () => {
        if (!account) {
            return
        }
        setIntervalTime(60)
        if (interval > 0) {
            return
        }
        let start = 60
        const timer = setInterval(() => {
            if (start > 0) {
                start--
                if (start <= 0) {
                    clearInterval(timer)
                }
                setIntervalTime(start)
            }
        }, 1000)
        const re = await sendCode(account)
        if (!re) return
        Taro.showToast({ title: '验证码发送成功', icon: 'success' })
    }

    const submit = async () => {
        if (!account || !smsCode || !pwd) {
            errorNotice('请完善信息')
            return
        }
        loading('手机号码修改中，请稍后～')
        const re = await phoneManage({
            new_phone: account,
            password: pwd,
            verification_code: smsCode
        })
        closeLoading()
        if (!re) return
        successNotice('手机号码修改成功')
        setTimeout(() => {
            backFn()
        }, 1000)
    }

    return <View className="login-frame bg-slate-50 h-screen text-base">
        <View className='addr-detail-title'>
            <Image src={backNav} className="square-35 absolute left-10 nav-icon" onClick={backFn} />
            修改手机号

        </View>
        <View className="change-pwd-container bg-slate-50 relative">
            <View>
                <View className="form-item mt-22">
                    <View className="form-label">密码</View>
                    <View className="form-control relative">
                        <Input className="form-input" type={showPwd ? 'text' : 'password'} placeholder="设置新密码" onInput={(v) => {
                            setPwd(v.detail.value)
                        }} />
                        <Image className="w-6 h-6 absolute right-0 bottom-16" src={showPwd ? activeEye : eyeClose} onClick={() => {
                            setShowPwd(v => !v)
                        }} />
                    </View>
                </View>
                <View className="form-item mt-22">
                    <View className="form-label">输入新手机号码</View>
                    <View className="form-control relative">
                        <Input className="form-input" type='text' placeholder="设置新手机号码" onInput={(v) => {
                            setAccount(v.detail.value)
                        }} />
                        {
                            account && <Image className="w-6 h-6 absolute right-0 bottom-16" src={checked} />
                        }
                    </View>
                </View>
                <View className="form-item mt-22">
                    <View className="form-label">验证码</View>
                    <View className="form-control relative">
                        <Input className="form-input" maxlength={6} placeholder="请输入验证码" onInput={(v) => {
                            setSmsCode(v.detail.value)
                        }} />
                        <Button className="code-btn" disabled={interval > 0} onClick={countDown}>{interval ? interval + 's' : '获取验证码'}</Button>
                    </View>
                </View>
                <View className="change-phone-footer flex flex-col justify-center">
                    <Button className="login-btn" onClick={submit}>保存</Button>

                </View>
            </View>

        </View>

    </View>
}


export default Login